==> jc-1.4.0.tar.gz: java/nio/channels/Pipe.h <==
// public abstract class java.nio.channels.Pipe

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2951d2f8b8defcbd java_nio_channels_Pipe

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_Pipe_H_
#define _JC_java_nio_channels_Pipe_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_Pipe$object;
struct _jc_java_nio_channels_Pipe__24SinkChannel$object;
struct _jc_java_nio_channels_Pipe__24SourceChannel$object;

// Typedefs
typedef struct _jc_java_nio_channels_Pipe$sub_refs	_jc_java_nio_channels_Pipe$sub_refs;
typedef struct _jc_java_nio_channels_Pipe$sub_nonrefs	_jc_java_nio_channels_Pipe$sub_nonrefs;
typedef struct _jc_java_nio_channels_Pipe$refs	_jc_java_nio_channels_Pipe$refs;
typedef struct _jc_java_nio_channels_Pipe$nonrefs	_jc_java_nio_channels_Pipe$nonrefs;
typedef struct _jc_java_nio_channels_Pipe$object	_jc_java_nio_channels_Pipe$object;

typedef const struct _jc_java_nio_channels_Pipe$vmethods	_jc_java_nio_channels_Pipe$vmethods;
typedef const struct _jc_java_nio_channels_Pipe$vtable	_jc_java_nio_channels_Pipe$vtable;
typedef const struct _jc_java_nio_channels_Pipe$vtype	_jc_java_nio_channels_Pipe$vtype;

// Constructors
extern void _jc_java_nio_channels_Pipe$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_Pipe$object *);

// Virtual methods
extern struct _jc_java_nio_channels_Pipe__24SinkChannel$object *_jc_java_nio_channels_Pipe$method$sink$a72af214bdd8aa6e(_jc_env *, struct _jc_java_nio_channels_Pipe$object *);
extern struct _jc_java_nio_channels_Pipe__24SourceChannel$object *_jc_java_nio_channels_Pipe$method$source$025193fa1d7529c6(_jc_env *, struct _jc_java_nio_channels_Pipe$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_Pipe$method_info$sink$a72af214bdd8aa6e;
extern _jc_method _jc_java_nio_channels_Pipe$method_info$source$025193fa1d7529c6;

// Static methods
extern struct _jc_java_nio_channels_Pipe$object *_jc_java_nio_channels_Pipe$method$open$c01270b8d8c80227(_jc_env *);

// Virtual methods structure
struct _jc_java_nio_channels_Pipe$vmethods {
	struct _jc_java_nio_channels_Pipe__24SinkChannel$object	*(*sink$a72af214bdd8aa6e)(_jc_env *, struct _jc_java_nio_channels_Pipe$object *);
	struct _jc_java_nio_channels_Pipe__24SourceChannel$object	*(*source$025193fa1d7529c6)(_jc_env *, struct _jc_java_nio_channels_Pipe$object *);
};

// Vtable
struct _jc_java_nio_channels_Pipe$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_Pipe$vmethods	java_nio_channels_Pipe;
};

// Vtype
struct _jc_java_nio_channels_Pipe$vtype {
	_jc_type			type;
	_jc_java_nio_channels_Pipe$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_Pipe$refs {
    _jc_java_nio_channels_Pipe$sub_refs	java_nio_channels_Pipe;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_Pipe$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_Pipe$sub_nonrefs	java_nio_channels_Pipe;
};

// Object instance structure
struct _jc_java_nio_channels_Pipe$object {
	_jc_java_nio_channels_Pipe$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_Pipe$vtype	*vtype;
	_jc_java_nio_channels_Pipe$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_Pipe$vtype _jc_java_nio_channels_Pipe$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_Pipe, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_Pipe$class_object;

#endif	/* _JC_java_nio_channels_Pipe_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/Pipe.h <==
// public abstract class java.nio.channels.Pipe

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2951d2f8b8defcbd java_nio_channels_Pipe

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_Pipe_H_
#define _JC_java_nio_channels_Pipe_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_Pipe$object;
struct _jc_java_nio_channels_Pipe__24SinkChannel$object;
struct _jc_java_nio_channels_Pipe__24SourceChannel$object;

// Typedefs
typedef struct _jc_java_nio_channels_Pipe$sub_refs	_jc_java_nio_channels_Pipe$sub_refs;
typedef struct _jc_java_nio_channels_Pipe$sub_nonrefs	_jc_java_nio_channels_Pipe$sub_nonrefs;
typedef struct _jc_java_nio_channels_Pipe$refs	_jc_java_nio_channels_Pipe$refs;
typedef struct _jc_java_nio_channels_Pipe$nonrefs	_jc_java_nio_channels_Pipe$nonrefs;
typedef struct _jc_java_nio_channels_Pipe$object	_jc_java_nio_channels_Pipe$object;

typedef const struct _jc_java_nio_channels_Pipe$vmethods	_jc_java_nio_channels_Pipe$vmethods;
typedef const struct _jc_java_nio_channels_Pipe$vtable	_jc_java_nio_channels_Pipe$vtable;
typedef const struct _jc_java_nio_channels_Pipe$vtype	_jc_java_nio_channels_Pipe$vtype;

// Constructors
extern void _jc_java_nio_channels_Pipe$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_Pipe$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_channels_Pipe__24SinkChannel$object *_jc_java_nio_channels_Pipe$method$sink$a72af214bdd8aa6e(_jc_env *, struct _jc_java_nio_channels_Pipe$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_Pipe__24SourceChannel$object *_jc_java_nio_channels_Pipe$method$source$025193fa1d7529c6(_jc_env *, struct _jc_java_nio_channels_Pipe$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_Pipe$method_info$sink$a72af214bdd8aa6e;
extern _jc_method _jc_java_nio_channels_Pipe$method_info$source$025193fa1d7529c6;

// Static methods
extern struct _jc_java_nio_channels_Pipe$object *_jc_java_nio_channels_Pipe$method$open$c01270b8d8c80227(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_Pipe$vmethods {
	struct _jc_java_nio_channels_Pipe__24SinkChannel$object	*(*sink$a72af214bdd8aa6e)(_jc_env *, struct _jc_java_nio_channels_Pipe$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_Pipe__24SourceChannel$object	*(*source$025193fa1d7529c6)(_jc_env *, struct _jc_java_nio_channels_Pipe$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_channels_Pipe$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_Pipe$vmethods	java_nio_channels_Pipe;
};

// Vtype
struct _jc_java_nio_channels_Pipe$vtype {
	_jc_type			type;
	_jc_java_nio_channels_Pipe$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_Pipe$refs {
    _jc_java_nio_channels_Pipe$sub_refs	java_nio_channels_Pipe;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_Pipe$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_Pipe$sub_nonrefs	java_nio_channels_Pipe;
};

// Object instance structure
struct _jc_java_nio_channels_Pipe$object {
	_jc_java_nio_channels_Pipe$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_Pipe$vtype	*vtype;
	_jc_java_nio_channels_Pipe$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_Pipe$vtype _jc_java_nio_channels_Pipe$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_Pipe, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_Pipe$class_object;

#endif	/* _JC_java_nio_channels_Pipe_H_ */
